import 'package:equatable/equatable.dart';
import 'package:flutter/material.dart';
import 'package:hydrated_bloc/hydrated_bloc.dart';

import 'package:petitbac/models/settings_game.dart';
import 'package:petitbac/utils/tools.dart';

part 'settings_game_state.dart';

class GameSettingsCubit extends HydratedCubit<GameSettingsState> {
  GameSettingsCubit() : super(GameSettingsState(settings: GameSettings.createDefault()));

  void setValues({
    int? itemsCount,
    int? timerValue,
  }) {
    emit(
      GameSettingsState(
        settings: GameSettings(
          itemsCount: itemsCount ?? state.settings.itemsCount,
          timerValue: timerValue ?? state.settings.timerValue,
        ),
      ),
    );
  }

  int getParameterValue(String code) {
    switch (code) {
      case 'itemsCount':
        return GameSettings.getItemsCountValueFromUnsafe(state.settings.itemsCount);
      case 'timerValue':
        return GameSettings.getTimerValueFromUnsafe(state.settings.timerValue);
    }
    return 0;
  }

  void setParameterValue(String code, int value) {
    printlog('GameSettingsCubit.setParameterValue');
    printlog('code: $code / value: $value');

    int itemsCount = code == 'itemsCount' ? value : getParameterValue('itemsCount');
    int timerValue = code == 'timerValue' ? value : getParameterValue('timerValue');

    setValues(
      itemsCount: itemsCount,
      timerValue: timerValue,
    );
  }

  @override
  GameSettingsState? fromJson(Map<String, dynamic> json) {
    int itemsCount = json['itemsCount'] as int;
    int timerValue = json['timerValue'] as int;

    return GameSettingsState(
      settings: GameSettings(
        itemsCount: itemsCount,
        timerValue: timerValue,
      ),
    );
  }

  @override
  Map<String, dynamic>? toJson(GameSettingsState state) {
    return <String, dynamic>{
      'itemsCount': state.settings.itemsCount,
      'timerValue': state.settings.timerValue,
    };
  }
}
