import 'package:petitbac/data/fetch_data_helper.dart';
import 'package:petitbac/models/data/category.dart';
import 'package:petitbac/models/data/game_item.dart';
import 'package:petitbac/models/data/letter.dart';
import 'package:petitbac/models/settings_game.dart';
import 'package:petitbac/models/settings_global.dart';
import 'package:petitbac/utils/tools.dart';

class Game {
  final List<GameItem> items;
  final GameSettings gameSettings;
  final GlobalSettings globalSettings;
  int countdown = 0;
  int position = 0;
  bool isRunning = false;
  bool isFinished = false;

  Game({
    required this.items,
    required this.gameSettings,
    required this.globalSettings,
    required this.countdown,
    required this.position,
    this.isRunning = false,
    this.isFinished = false,
  });

  factory Game.createNull() {
    return Game(
      items: [],
      gameSettings: GameSettings.createDefault(),
      globalSettings: GlobalSettings.createDefault(),
      countdown: 0,
      position: 0,
    );
  }

  factory Game.createNew({
    GameSettings? gameSettings,
    GlobalSettings? globalSettings,
  }) {
    GameSettings newGameSettings = gameSettings ?? GameSettings.createDefault();
    GlobalSettings newGlobalSettings = globalSettings ?? GlobalSettings.createDefault();

    List<GameItem> items = FetchDataHelper().getRandomItems(newGameSettings.itemsCount);

    return Game(
      items: items,
      gameSettings: newGameSettings,
      globalSettings: newGlobalSettings,
      countdown: 0,
      position: 0,
      isRunning: true,
      isFinished: false,
    );
  }

  void stop() {
    isRunning = false;
  }

  GameItem get item => items[position];
  Category get category => item.category;
  Letter get letter => item.letter;

  void dump() {
    printlog('');
    printlog('## Current game dump:');
    printlog('');
    gameSettings.dump();
    globalSettings.dump();
    printlog('');
    printlog('items:');
    printlog(items.toString());
    printlog('');
    printlog('Game: ');
    printlog('  isRunning: $isRunning');
    printlog('  isFinished: $isFinished');
    printlog('  position: $position');
    printlog('  countdown: $countdown');
    printlog('');
  }

  @override
  String toString() {
    return '$Game(${toJson()})';
  }

  Map<String, dynamic>? toJson() {
    return <String, dynamic>{
      'items': items,
      'gameSettings': gameSettings,
      'globalSettings': globalSettings,
      'countdown': countdown,
      'position': position,
      'isRunning': isRunning,
      'isFinished': isFinished,
    };
  }
}
